summaryrefslogtreecommitdiff
path: root/chickadee/scripting.scm
diff options
context:
space:
mode:
Diffstat (limited to 'chickadee/scripting.scm')
-rw-r--r--chickadee/scripting.scm10
1 files changed, 5 insertions, 5 deletions
diff --git a/chickadee/scripting.scm b/chickadee/scripting.scm
index 0e29fa6..d88e422 100644
--- a/chickadee/scripting.scm
+++ b/chickadee/scripting.scm
@@ -20,7 +20,7 @@
#:use-module (chickadee math easings)
#:use-module (chickadee scripting agenda)
#:use-module (chickadee scripting channel)
- #:use-module (chickadee scripting coroutine)
+ #:use-module (chickadee scripting script)
#:export (forever
sleep
tween)
@@ -30,7 +30,7 @@
(eval-when (eval load compile)
(begin
(define %public-modules
- '(agenda channel coroutine))
+ '(agenda channel script))
(for-each (let ((i (module-public-interface (current-module))))
(lambda (m)
(module-use! i (resolve-interface
@@ -42,9 +42,9 @@
(while #t body ...))
(define (sleep duration)
- "Wait DURATION before resuming the current coroutine."
- ;; Capture the current agenda before suspending the coroutine so
- ;; that we schedule the continuation in the right place.
+ "Wait DURATION before resuming the current script."
+ ;; Capture the current agenda before suspending the script so that
+ ;; we schedule the continuation in the right place.
(let ((agenda (current-agenda)))
(yield
(lambda (cont)